==> huaweicloudsdkcbs-3.1.38-py2.py3-none-any.whl: huaweicloudsdkcbs/v1/model/execute_get_frams_list_by_images_id_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ExecuteGetFramsListByImagesIdRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'image_id': 'str'
    }

    attribute_map = {
        'image_id': 'image_id'
    }

    def __init__(self, image_id=None):
        """ExecuteGetFramsListByImagesIdRequest

        The model defined in huaweicloud sdk

        :param image_id: 图片id
        :type image_id: str
        """
        
        

        self._image_id = None
        self.discriminator = None

        self.image_id = image_id

    @property
    def image_id(self):
        """Gets the image_id of this ExecuteGetFramsListByImagesIdRequest.

        图片id

        :return: The image_id of this ExecuteGetFramsListByImagesIdRequest.
        :rtype: str
        """
        return self._image_id

    @image_id.setter
    def image_id(self, image_id):
        """Sets the image_id of this ExecuteGetFramsListByImagesIdRequest.

        图片id

        :param image_id: The image_id of this ExecuteGetFramsListByImagesIdRequest.
        :type image_id: str
        """
        self._image_id = image_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExecuteGetFramsListByImagesIdRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcbs-3.1.74-py2.py3-none-any.whl: huaweicloudsdkcbs/v1/model/execute_get_frams_list_by_images_id_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ExecuteGetFramsListByImagesIdRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'image_id': 'str',
        'offset': 'int',
        'limit': 'int'
    }

    attribute_map = {
        'image_id': 'image_id',
        'offset': 'offset',
        'limit': 'limit'
    }

    def __init__(self, image_id=None, offset=None, limit=None):
        """ExecuteGetFramsListByImagesIdRequest

        The model defined in huaweicloud sdk

        :param image_id: 图片id
        :type image_id: str
        :param offset: 偏移量，默认为零
        :type offset: int
        :param limit: 分页限制数
        :type limit: int
        """
        
        

        self._image_id = None
        self._offset = None
        self._limit = None
        self.discriminator = None

        self.image_id = image_id
        if offset is not None:
            self.offset = offset
        if limit is not None:
            self.limit = limit

    @property
    def image_id(self):
        """Gets the image_id of this ExecuteGetFramsListByImagesIdRequest.

        图片id

        :return: The image_id of this ExecuteGetFramsListByImagesIdRequest.
        :rtype: str
        """
        return self._image_id

    @image_id.setter
    def image_id(self, image_id):
        """Sets the image_id of this ExecuteGetFramsListByImagesIdRequest.

        图片id

        :param image_id: The image_id of this ExecuteGetFramsListByImagesIdRequest.
        :type image_id: str
        """
        self._image_id = image_id

    @property
    def offset(self):
        """Gets the offset of this ExecuteGetFramsListByImagesIdRequest.

        偏移量，默认为零

        :return: The offset of this ExecuteGetFramsListByImagesIdRequest.
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this ExecuteGetFramsListByImagesIdRequest.

        偏移量，默认为零

        :param offset: The offset of this ExecuteGetFramsListByImagesIdRequest.
        :type offset: int
        """
        self._offset = offset

    @property
    def limit(self):
        """Gets the limit of this ExecuteGetFramsListByImagesIdRequest.

        分页限制数

        :return: The limit of this ExecuteGetFramsListByImagesIdRequest.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this ExecuteGetFramsListByImagesIdRequest.

        分页限制数

        :param limit: The limit of this ExecuteGetFramsListByImagesIdRequest.
        :type limit: int
        """
        self._limit = limit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExecuteGetFramsListByImagesIdRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
